==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/cs.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Správa parametrů Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Správa Galerie");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Width");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Výška");
define('MANAGE_GALLERY_THUMB_WIDTH', "Náhled Šířka obrázku");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Náhledy Výška Image");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Zachovat Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Ukázat tituly");
define('MANAGE_GALLERY_DISABLE_SORT', "Zakázat Třídit");
define('MANAGE_GALLERY_DELETE_IMAGE', "smazat obrázek");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Uložení Třídit Objednávka");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klikněte na &#39;Aktualizovat&#39; publikovat <br /> nahrané obrázky.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Všechny obrazy byly zmenšeny a byly uloženy nastavení.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Došlo k chybě při změně velikosti obrázků nebo uložení nastavení.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Disk (y) byl nahrán.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Došlo k chybě při nahrávání na disk (y).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Soubor, který se pokoušíte nahrát, není obrázek.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Soubor, který se pokoušíte nahrát, je příliš velký.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Titul byl uložen.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Jste si jisti, že chcete smazat snímek");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Obraz byl smazán.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Došlo k chybě při mazání obraz.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Uložení parametrů a změnu velikosti obrázků, čekejte prosím ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Nahrávání, čekejte prosím ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Pořadí řazení nebyl uložen. Chcete ušetřit pořadí řazení?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Obraz třídění objednávka byla uložena.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Nastala chyba při ukládání obrázku třídění.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/cs.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Správa parametrů Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Správa Galerie");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Width");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Výška");
define('MANAGE_GALLERY_THUMB_WIDTH', "Náhled Šířka obrázku");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Náhledy Výška Image");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Zachovat Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Ukázat tituly");
define('MANAGE_GALLERY_DISABLE_SORT', "Zakázat Třídit");
define('MANAGE_GALLERY_DELETE_IMAGE', "smazat obrázek");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Uložení Třídit Objednávka");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klikněte na &#39;Aktualizovat&#39; publikovat <br /> nahrané obrázky.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Všechny obrazy byly zmenšeny a byly uloženy nastavení.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Došlo k chybě při změně velikosti obrázků nebo uložení nastavení.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Disk (y) byl nahrán.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Došlo k chybě při nahrávání na disk (y).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Soubor, který se pokoušíte nahrát, není obrázek.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Soubor, který se pokoušíte nahrát, je příliš velký.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Titul byl uložen.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Jste si jisti, že chcete smazat snímek");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Obraz byl smazán.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Došlo k chybě při mazání obraz.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Uložení parametrů a změnu velikosti obrázků, čekejte prosím ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Nahrávání, čekejte prosím ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Pořadí řazení nebyl uložen. Chcete ušetřit pořadí řazení?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Obraz třídění objednávka byla uložena.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Nastala chyba při ukládání obrázku třídění.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Soubor, který se pokoušíte nahrát, je větší než nastavení PHP „upload_max_filesize“ nebo „post_max_size“ PHP. Chcete-li tyto limity zvýšit, obraťte se na správce systému.");
?>
